Determining scales for mosaics
Usage
scale_x_productlist(
name = ggplot2::waiver(),
breaks = product_breaks(),
minor_breaks = NULL,
labels = product_labels(),
limits = NULL,
expand = ggplot2::waiver(),
oob = scales::censor,
na.value = NA_real_,
position = "bottom",
sec.axis = ggplot2::waiver()
)
scale_y_productlist(
name = ggplot2::waiver(),
breaks = product_breaks(),
minor_breaks = NULL,
labels = product_labels(),
limits = NULL,
expand = ggplot2::waiver(),
oob = scales::censor,
na.value = NA_real_,
position = "left",
sec.axis = ggplot2::waiver()
)
ScaleContinuousProductFormat
An object of class ScaleContinuousProduct (inherits from ScaleContinuousPosition, ScaleContinuous, Scale, ggproto, gg) of length 5.
Arguments
- name
set to pseudo waiver function
product_namesby default.- breaks
One of:
NULLfor no breakswaiver()for the default breaks computed by the transformation objectA numeric vector of positions
A function that takes the limits as input and returns breaks as output (e.g., a function returned by
scales::extended_breaks()). Note that for position scales, limits are provided after scale expansion. Also accepts rlang lambda function notation.
- minor_breaks
One of:
NULLfor no minor breakswaiver()for the default breaks (none for discrete, one minor break between each major break for continuous)A numeric vector of positions
A function that given the limits returns a vector of minor breaks. Also accepts rlang lambda function notation. When the function has two arguments, it will be given the limits and major break positions.
- labels
One of the options below. Please note that when
labelsis a vector, it is highly recommended to also set thebreaksargument as a vector to protect against unintended mismatches.NULLfor no labelswaiver()for the default labels computed by the transformation objectA character vector giving labels (must be same length as
breaks)An expression vector (must be the same length as breaks). See ?plotmath for details.
A function that takes the breaks as input and returns labels as output. Also accepts rlang lambda function notation.
- limits
One of:
NULLto use the default scale rangeA numeric vector of length two providing limits of the scale. Use
NAto refer to the existing minimum or maximumA function that accepts the existing (automatic) limits and returns new limits. Also accepts rlang lambda function notation. Note that setting limits on positional scales will remove data outside of the limits. If the purpose is to zoom, use the limit argument in the coordinate system (see
coord_cartesian()).
- expand
For position scales, a vector of range expansion constants used to add some padding around the data to ensure that they are placed some distance away from the axes. Use the convenience function
expansion()to generate the values for theexpandargument. The defaults are to expand the scale by 5% on each side for continuous variables, and by 0.6 units on each side for discrete variables.- oob
One of:
Function that handles limits outside of the scale limits (out of bounds). Also accepts rlang lambda function notation.
The default (
scales::censor()) replaces out of bounds values withNA.scales::squish()for squishing out of bounds values into range.scales::squish_infinite()for squishing infinite values into range.
- na.value
Missing values will be replaced with this value.
- position
For position scales, The position of the axis.
leftorrightfor y axes,toporbottomfor x axes.- sec.axis
specify a secondary axis